@@ -235,6 +235,8 @@ newindex= lambda idxname : (requests.es.indices.delete(idxname) if requests.es.i
 rows	= lambda query: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json().get('rows',[]) 
 sql		= lambda query: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json().get('rows',[]) 
 sntnum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0][0] #75222
+sntsum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0][0] # added 2022.6.29
+lexsum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'tok'" )[0][0] 
 lexnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where low = '{w}' and type = 'tok'")[0][0] # opened = 70
 lemnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where lem = '{w}' and type = 'tok'")[0][0] 
 sqlsi	= lambda query: (si:=Counter(), [si.update({row[0]:1}) for row in sql(query)])[0]
