@@ -3,7 +3,7 @@ from uvirun import *
 from util import likelihood
 import pandas as pd
 import requests, requests_cache
-requests_cache.install_cache('cos_cache') # walk over, to load all, to fill the cache , to be used offline 
+requests_cache.install_cache('/data/model/cos/cos_cache') # walk over, to load all, to fill the cache , to be used offline 
 cos_url = os.getenv('cos_url', 'https://json-1257827020.cos.ap-shanghai.myqcloud.com') #cos  = lambda key="bnc.pos.VERB": requests.get(f"https://json-1257827020.cos.ap-shanghai.myqcloud.com/{key}").json()
 
 @app.get('/cos')
@@ -29,6 +29,11 @@ def cos_keyness(suffix:str="poslemcnt",  hkey:str='VERB', cp1:str='clec', cp2:st
 	words = set( [ k for k,v in arr1.items()] ).union(set( [ k for k,v in arr2.items()] )) if words is None else words.strip().split(',')
 	return [(w, arr1.get(w,0), arr2.get(w,0), likelihood(arr1.get(w,0), arr2.get(w,0), sum1, sum2))  for w in words]
 
+@app.get('/cos/lemma_keyness')
+def cos_lemma_keyness(hkey:str='VERB', hval:str='consider', cp1:str='clec', cp2:str='dic', suffix:str="poslemcnt"): 
+	'''  '''
+	return  likelihood( cosget(f"{cp1}.{suffix}", hkey).get(hval, 0), cosget(f"{cp2}.{suffix}", hkey).get(hval, 0), cosget(f"{cp1}.{suffix}", "_sntsum", 1), cosget(f"{cp2}.{suffix}", "_sntsum", 1))
+
 cos_ssi_mf =lambda key="dic.dobj_VERB_NOUN", hkey='open', hval='door': round(cos(key).get(hkey, {}).get(hval, 0) * 1000000 / cos(key).get('_sntsum', 1) , 2)
 @app.get('/cos/trp_mf')
 def cos_trp_mf(cps:str='clec,gzjc,dic,bnc,twit', rel:str='dobj_VERB_NOUN', gov:str='learn', dep:str='knowledge'): 
@@ -65,6 +70,5 @@ def cos_trpvs(w:str='knowledge', rel:str='~dobj_VERB_NOUN', cp1:str='clec', cp2:
 	arr = [ dict(dict(row), **{"term": index} ) for index, row in df.iterrows()] 
 	return arr[0:topk] if topk > 0  else arr 
 
-if __name__ == "__main__":  
-	print ( cos_trpvs()) 
-	uvicorn.run(app, host='0.0.0.0', port=80)
+if __name__ == "__main__":   #uvicorn.run(app, host='0.0.0.0', port=80)
+	print ( cos_lemma_keyness()) 	
\ No newline at end of file
