@@ -17,7 +17,7 @@ def mkf_input(snts, docs, tokenizer, sntdic:dict={},diffmerge:bool=False):
 				for i, doc in enumerate(docs)]
 	return input #mkfs	= requests.post(f"http://172.17.0.1:7095/parser", data={"q":json.dumps(input).encode("utf-8")}).json()
 
-@app.get('/register_redis')
+@app.get('/dsk/register_redis')
 def register_redis(rinfo:str='172.17.0.1:6379:0'):
 	''' to enable redis cache for snt parsing , 2022.6.30 '''
 	en.redis_xsntbytes = en.register_redis(rinfo, force=True)
@@ -49,11 +49,11 @@ def post_dsk(arr:dict={'essay_or_snts':"She has ready. It are ok.", # arr from m
 		tims	= [ ("start", time.time(), 0)] # tag, tm, delta 
 		essay_or_snts = arr.get("essay_or_snts","")
 		snts	= json.loads(essay_or_snts) if essay_or_snts.startswith("[") else en.sntbr(essay_or_snts)
-		if en.redis_xsntbytes: en.publish_newsnts(snts) 
+		if hasattr(en,'redis_xsntbytes'): en.publish_newsnts(snts) 
 
 		sntdic	= gecsnts(snts) # # localversion, return {'She has ready.': 'She is ready.', 'It are ok.': 'It is ok.'}
 		if debug : tims.append( ("gec", time.time(), round(time.time() - tims[-1][1],2))  )
-		docs	= [ en.parse_if(snt) if en.redis_xsntbytes else spacy.nlp(snt) for snt in snts ] 
+		docs	= [ en.parse_if(snt) if hasattr(en,'redis_xsntbytes') else spacy.nlp(snt) for snt in snts ] 
 		if debug : tims.append( ("nlp", time.time(), round(time.time() - tims[-1][1],2))  )
 		input	= mkf_input(snts, docs, spacy.nlp.tokenizer, sntdic)
 		res		= requests.post(f"http://{dskhost}/parser", data={"q":json.dumps({"snts":input, "rid":"10"} if asdsk else input).encode("utf-8")}).json()
