@@ -12,6 +12,14 @@ requests.es		= Elasticsearch([ f"http://{requests.eshost}:{requests.esport}" ])
 # to be removed later, when cikuu is updated
 kwic	= lambda cp, w, topk=3 : [ re.sub(rf"\b({w})\b", f"<b>{w}</b>", row[0]) for row in rows(f"select snt from {cp} where type = 'snt' and match (snt, '{w}') limit {topk}")]
 
+@app.get('/es/xcnt/{cp}/{type}/{column}')
+def es_xcnt( column:str='lex', cp:str='dic', type:str='tok', where:str="", order:str="order by cnt desc limit 10",  name:str="es.corpusly.com:9200" ):
+	''' where:  and lem='book'  | JSONCompactColumns
+	* select lex,count(*) cnt from dic where type = 'tok' and lem= 'book' group by lex '''
+	query  = f"select {column}, count(*) cnt from {cp} where type = '{type}' {where} group by {column} {order}"
+	res = requests.post(f"http://{name}/_sql",json={"query": query}).json() 
+	return [  { column: ar[0], "cnt": ar[1]} for ar in res['rows'] ] 
+
 @app.get('/es/sqlrows')
 def sqlrows(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10", perc_column:str=None):
 	''' perc_column: cnt  
@@ -90,13 +98,13 @@ def corpus_srcsnts(query:str="select src from gzjc where type='tok' and lem='boo
 	srclist = "','".join([ src for src, in rows(query)])
 	return [{'snt':re.sub(rf"\b({highlight})\b", f"{left_tag}{highlight}{right_tag}", snt)} for snt, in rows(f"select snt from {cp} where type='snt' and src in ('{srclist}')")]
 
-@app.get("/lempos/snts")
+@app.get("/es/lempos/snts")
 def lempos_snts(cp:str='gzjc', lem:str='book', pos:str='VERB', topk:int=3, left_tag:str="<b>", right_tag:str="</b>"): 
 	''' "select snt from gzjc where type = 'snt' and kp = 'book_VERB' limit 2" , added 2022.6.24 '''
 	query = f"select snt from {cp} where type = 'snt' and kp = '{lem}_{pos}' limit {topk}"
 	return [{'snt':re.sub(rf"\b({lem})\b", f"{left_tag}{lem}{right_tag}", snt)} for snt, in rows(query)]	
 
-@app.get("/trp/snts")
+@app.get("/es/trp/snts")
 def trp_snts(cp:str='gzjc', word:str='door', rel:str='~dobj_VERB_NOUN', cur:str='open',  topk:int=3): 
 	query = f"select snt from {cp} where type = 'snt' and kp = '{rel[1:]}/{cur} {word}' limit {topk}" if rel.startswith('~') else f"select snt from {cp} where type = 'snt' and kp = '{rel}/{word} {cur}' limit {topk}"
 	print (query, flush=True)
@@ -136,6 +144,5 @@ def text_keyness(sql1:str= "select lem,  count(*) from inau where type = 'tok' a
 @app.get('/es/init_index')
 def init_index(idxname:str='testidx'):  requests.es.newindex(idxname)
 
-if __name__ == "__main__":  
-	print (es_query_termcnt())
-	uvicorn.run(app, host='0.0.0.0', port=80)
\ No newline at end of file
+if __name__ == "__main__":   #uvicorn.run(app, host='0.0.0.0', port=80)
+	print (sqlrows())	
\ No newline at end of file
