@@ -4,12 +4,14 @@ import spacy
 if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_sm')
 
 @app.get('/spacy/toks')
-def spacy_toks(text:str='The boy is happy. The quick fox jumped over the lazy dog.',chunks:bool=False, sino:str='sino', native:str='bnc'): #[{'i': 0, 'head': 1, 'lex': 'The', 'lem': 'the', 'pos': 'DET', 'tag': 'DT', 'dep': 'det', 'gov': 'boy_NOUN', 'chunks': []}, {'i': 1, 'head': 2, 'lex': 'boy', 'lem': 'boy', 'pos': 'NOUN', 'tag': 'NN', 'dep': 'nsubj', 'gov': 'be_AUX', 'chunks': [{'lempos': 'boy_NOUN', 'type': 'NP', 'chunk': 'the boy'}]}, {'i': 2, 'head': 2, 'lex': 'is', 'lem': 'be', 'pos': 'AUX', 'tag': 'VBZ', 'dep': 'ROOT', 'gov': 'be_AUX', 'chunks': []}, {'i': 3, 'head': 2, 'lex': 'happy', 'lem': 'happy', 'pos': 'ADJ', 'tag': 'JJ', 'dep': 'acomp', 'gov': 'be_AUX', 'chunks': []}, {'i': 4, 'head': 2, 'lex': '.', 'lem': '.', 'pos': 'PUNCT', 'tag': '.', 'dep': 'punct', 'gov': 'be_AUX', 'chunks': []}]
-	''' JSONEachRow format , added 2022.6.25 ''' 
+def spacy_toks(text:str='The boy is happy. The quick fox jumped over the lazy dog.',chunks:bool=False, sino:str='sino', native:str='dic'): 
+	''' [{'i': 0, 'head': 1, 'lex': 'The', 'lem': 'the', 'pos': 'DET', 'tag': 'DT', 'dep': 'det', 'gov': 'boy_NOUN', 'chunks': []}, {'i': 1, 'head': 2, 'lex': 'boy', 'lem': 'boy', 'pos': 'NOUN', 'tag': 'NN', 'dep': 'nsubj', 'gov': 'be_AUX', 'chunks': [{'lempos': 'boy_NOUN', 'type': 'NP', 'chunk': 'the boy'}]}, {'i': 2, 'head': 2, 'lex': 'is', 'lem': 'be', 'pos': 'AUX', 'tag': 'VBZ', 'dep': 'ROOT', 'gov': 'be_AUX', 'chunks': []}, {'i': 3, 'head': 2, 'lex': 'happy', 'lem': 'happy', 'pos': 'ADJ', 'tag': 'JJ', 'dep': 'acomp', 'gov': 'be_AUX', 'chunks': []}, {'i': 4, 'head': 2, 'lex': '.', 'lem': '.', 'pos': 'PUNCT', 'tag': '.', 'dep': 'punct', 'gov': 'be_AUX', 'chunks': []}] JSONEachRow format , added 2022.6.25 ''' 
 	from dic.word_idf import word_idf 
 	from dic.word_awl import word_awl
+	from cos_fastapi  import cos_lemma_keyness
 	doc = spacy.nlp(text) 
-	dic = { t.i: {'i':t.i, "head":t.head.i, 'off':t.idx, 'idf': word_idf.get(t.text.lower(), 0),'awl': 1 if t.text.lower() in word_awl else 0, 'keyness': cos_keyness(t.lemma_, t.pos_, sino, native) if t.pos_ in ('NOUN','VERB','ADJ','ADV') else 0 , 
+	dic = { t.i: {'i':t.i, "head":t.head.i, 'off':t.idx, 'idf': word_idf.get(t.text.lower(), 0),'awl': 1 if t.text.lower() in word_awl else 0, 
+		'keyness': cos_lemma_keyness(t.pos_, t.lemma_, sino, native) if t.pos_ in ('NOUN','VERB','ADJ','ADV') else 0 , 
 		'lex':t.text, 'text_with_ws':t.text_with_ws, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gov":t.head.lemma_ + "_" + t.head.pos_ }  for t in doc}
 	if chunks: 
 		[v.update({"chunks":[]}) for k,v in dic.items()]
@@ -23,7 +25,7 @@ def doc_highlight(text:str='The boy is happy. The quick fox jumped over the lazy
 	arr = [ ("<b>" if t.pos_ == pos else "") + t.text_with_ws + ("</b>" if t.pos_ == pos else "") for t in doc]
 	return "".join(arr) 
 
-@app.get('/dsk')
+@app.get('/spacy/dsk')
 def dsk(text:str='The boy is happy. The quick fox jumped over the lazy dog.'):
 	res = requests.post("http://gpu120.wrask.com:8180/gecdsk", json={"essay_or_snts":text}).json()
 	snts = [ dict( mkf.get("meta",{}), **{"feedback": [ v for cate, v in mkf.get('feedback',{}).items() ] } ) for mkf in res.get('snt',[])]
@@ -33,7 +35,7 @@ def dsk(text:str='The boy is happy. The quick fox jumped over the lazy dog.'):
 	"info": res.get('info',{}), 
 	}
 
-@app.get("/nlp/terms")
+@app.get("/spacy/terms")
 def nlp_terms(text:str="The quick fox jumped over the lazy dog. The justice delayed is justice denied."):
 	''' for sqlite indexing, 2022.3.4 '''
 	tdoc = spacy.nlp(text)
@@ -47,17 +49,16 @@ def nlp_terms(text:str="The quick fox jumped over the lazy dog. The justice dela
 		} )
 	return arr 
 
-@app.get("/nlp/sntbr")
+@app.get("/spacy/sntbr")
 def nlp_sntbr(text:str="The quick fox jumped over the lazy dog. The justice delayed is justice denied.", trim:bool=True):
 	'''  '''
-	return spacy.snts(text, trim) 
+	return spacy.sntbr(text, trim) 
 
-@app.post("/nlp/wordidf")
+@app.post("/spacy/wordidf")
 def nlp_wordidf(words:list=["niche","dilemma","consider","consider**"], default_idf:float=0):
 	'''  '''
 	from dic.word_idf import word_idf 
 	return  { w: word_idf.get(w, default_idf) for w in words}
 
-if __name__ == "__main__":  
-	print (spacy_toks())
-	#uvicorn.run(app, host='0.0.0.0', port=19200)
\ No newline at end of file
+if __name__ == "__main__":  #uvicorn.run(app, host='0.0.0.0', port=19200)
+	print (spacy_toks())	
\ No newline at end of file
