@@ -3,27 +3,27 @@ from uvirun import *
 import textacy,spacy
 if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_sm')
 
-@app.get('/textai/keyword_in_context')
+@app.get('/textacy/keyword_in_context')
 def keyword_in_context(text:str="The quick fox jumped over the lazy dog.", keyword:str="jumped", window_width:int=25, pad_context:bool=True): 
 	''' 2022.1.28	'''
 	from textacy import extract
 	return list(extract.keyword_in_context(text, keyword, window_width=window_width, pad_context=pad_context))
 
-@app.get('/textai/ngrams')
+@app.get('/textacy/ngrams')
 def ngrams(text:str="The quick fox jumped over the lazy dog.",n:int=3,filter_stops:bool=True, filter_punct:bool=True, filter_nums:bool=False, min_freq:int=1): 
 	''' 2022.1.28	'''
 	doc = spacy.nlp(text)
 	return list(textacy.extract.ngrams(
 	   doc, n, filter_stops=filter_stops, filter_punct=filter_punct, filter_nums=filter_nums,min_freq=min_freq))
 
-@app.get('/textai/keyterms')
+@app.get('/textacy/keyterms')
 def textacy_keyterms(text:str="The quick fox jumped over the lazy dog.",normalize:str='orth', topn:int=10): 
 	''' normalize: lemma/lower/orth, 2022.1.28	'''
 	from textacy.extract import keyterms as kt
 	doc = spacy.nlp(text)
 	return kt.textrank(doc, normalize=normalize, topn=topn)
 
-@app.get('/textai/textstats')
+@app.get('/textacy/textstats')
 def textacy_TextStats(text:str="The quick fox jumped over the lazy dog.", diversity:str=None, readability:str="automated_readability_index,automatic_arabic_readability_index,coleman_liau_index,flesch_kincaid_grade_level,flesch_reading_ease,gulpease_index,gunning_fog_index,lix,mu_legibility_index,perspicuity_index,smog_index,wiener_sachtextformel"): 
 	'''  diversity:['hdd', 'log_ttr', 'mtld', 'segmented_ttr', 'ttr']	'''
 	from textacy import text_stats
